@@ -263,7 +263,7 @@ qint32 TouchEvent::id() const
 {
     Q_ASSERT(type() != LIBINPUT_EVENT_TOUCH_CANCEL && type() != LIBINPUT_EVENT_TOUCH_FRAME);
 
-    const qint32 slot = libinput_event_touch_get_slot(m_touchEvent);
+    const qint32 slot = libinput_event_touch_get_seat_slot(m_touchEvent);
 
     return slot == -1 ? 0 : slot;
 }
