@@ -18,9 +18,6 @@ public:
 
     bool isEffectAvailable(KWindowEffects::Effect effect) override;
     void slideWindow(WId id, KWindowEffects::SlideFromLocation location, int offset) override;
-#if KWINDOWSYSTEM_VERSION <= QT_VERSION_CHECK(5, 61, 0)
-    void slideWindow(QWidget *widget, KWindowEffects::SlideFromLocation location) override;
-#endif
     QList<QSize> windowSizes(const QList<WId> &ids) override;
     void presentWindows(WId controller, const QList<WId> &ids) override;
     void presentWindows(WId controller, int desktop = NET::OnAllDesktops) override;
