@@ -44,8 +44,6 @@ WaylandClient::WaylandClient(SurfaceInterface *surface)
     setSurface(surface);
     setupCompositing();
 
-    m_windowId = waylandServer()->createWindowId(surface);
-
     connect(surface, &SurfaceInterface::shadowChanged,
             this, &WaylandClient::updateShadow);
     connect(this, &WaylandClient::frameGeometryChanged,
@@ -94,11 +92,6 @@ QRect WaylandClient::transparentRect() const
     return QRect();
 }
 
-quint32 WaylandClient::windowId() const
-{
-    return m_windowId;
-}
-
 pid_t WaylandClient::pid() const
 {
     return surface()->client()->processId();
@@ -273,7 +266,7 @@ void WaylandClient::doSetActive()
 
 void WaylandClient::updateDepth()
 {
-    if (surface()->buffer()->hasAlphaChannel() && !isDesktop()) {
+    if (surface()->buffer()->hasAlphaChannel()) {
         setDepth(32);
     } else {
         setDepth(24);
