@@ -115,6 +115,7 @@ public:
      */
     X11Client *findClient(std::function<bool (const X11Client *)> func) const;
     AbstractClient *findAbstractClient(std::function<bool (const AbstractClient*)> func) const;
+    AbstractClient *findAbstractClient(const QUuid &internalId) const;
     /**
      * @brief Finds the Client matching the given match @p predicate for the given window.
      *
@@ -517,7 +518,7 @@ Q_SIGNALS:
     void configChanged();
     void showingDesktopChanged(bool showing);
     /**
-     * This signels is emitted when ever the stacking order is change, ie. a window is risen
+     * This signal is emitted when the stacking order changed, i.e. a window is risen
      * or lowered
      */
     void stackingOrderChanged();
