@@ -755,6 +755,7 @@ void XdgToplevelClient::handleRoleCommit()
     if (configureEvent) {
         handleStatesAcknowledged(configureEvent->states);
     }
+    updateDecoration(false, false);
 }
 
 void XdgToplevelClient::doMinimize()
@@ -1303,11 +1304,6 @@ void XdgToplevelClient::installXdgDecoration(XdgToplevelDecorationV1Interface *d
 {
     m_xdgDecoration = decoration;
 
-    connect(m_xdgDecoration, &XdgToplevelDecorationV1Interface::destroyed, this, [this] {
-        if (!isZombie() && m_isInitialized) {
-            updateDecoration(/* check_workspace_pos */ true);
-        }
-    });
     connect(m_xdgDecoration, &XdgToplevelDecorationV1Interface::preferredModeChanged, this, [this] {
         if (m_isInitialized) {
             // force is true as we must send a new configure response.
@@ -1711,7 +1707,7 @@ XdgPopupClient::XdgPopupClient(XdgPopupInterface *shellSurface)
             this, &XdgPopupClient::destroyClient);
 }
 
-void XdgPopupClient::handlePositionerBindings()
+void XdgPopupClient::updateReactive()
 {
     if (m_shellSurface->positioner().isReactive()) {
         connect(transientFor(), &AbstractClient::frameGeometryChanged,
@@ -1724,7 +1720,7 @@ void XdgPopupClient::handlePositionerBindings()
 
 void XdgPopupClient::handleRepositionRequested(quint32 token)
 {
-    handlePositionerBindings();
+    updateReactive();
     m_shellSurface->sendRepositioned(token);
     relayout();
 }
@@ -2016,6 +2012,8 @@ void XdgPopupClient::initialize()
     parentClient->addTransient(this);
     setTransientFor(parentClient);
 
+    updateReactive();
+
     blockGeometryUpdates(true);
     const QRect area = workspace()->clientArea(PlacementArea, Screens::self()->current(), desktop());
     placeIn(area);
